
RELEASE_VERSION='0.0.451799019'
BUILD_DATE='Wed Jan 19 17:18:02 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-06xw98 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1993102344'
GIT_COMMIT_SHA='aab67b57ac9fc0032d2aaba0d403aebbebfb1a2e'
GIT_BRANCH='main'
